@@ -3,8 +3,8 @@
 
     Disk Based Hash library DBH
 
- * Copyright (C) 2002-2015 Edscott Wilson Garcia
- * EMail: edscott@xfce.org
+ * Copyright (C) 2002-2016 Edscott Wilson Garcia
+ * EMail: edscott@imp.mc
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -37,7 +37,10 @@ DBH version 2 requires size_t to be at least 64 bits to compile.
 
 If sizeof(size_t) is less than 64 bits, DBH version 2.0 will not compile
 ****************************************************************************/
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include "debug.h"
 #include <stdio.h>
 #include <time.h>
