@@ -4,8 +4,8 @@
 
 
     Header file.
- * Copyright (C) 2002-2015 Edscott Wilson Garcia
- * EMail: edscott@xfce.org
+ * Copyright (C) 2002-2016 Edscott Wilson Garcia
+ * EMail: edscott@imp.mx
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -48,7 +48,7 @@ extern "C" {
  * Disk Based Hashtables library version
  *
  **/
-#define DBH_VERSION 		"5.0.19"
+#define DBH_VERSION 		"5.0.22"
 
 #undef DBH_FILE_VERSION
 /**
@@ -382,9 +382,9 @@ struct _DBHashTable
   struct _DBHashTable *dbh_desdbh;
   int protection_flags;
   pthread_mutex_t  *mutex;
+  int lock_attempt_limit;
 #ifdef PARALLEL_SAFE
   dbh_lock_t *lock_p;
-  int lock_attempt_limit;
   sem_t *sem;
 #endif
 } ;
@@ -694,6 +694,21 @@ int dbh_unprune (DBHashTable * dbh,
 		 unsigned char *key, unsigned char subtree_length);
 
 
+/**
+ * dbh_find_top:
+ * @dbh: A #DBHashTable pointer (#DBHashTable *).
+ * @n: Number of branches to match on top record.
+ * @Returns: 0 on error, byte offset of loaded record otherwise.
+ *
+ * Find the top level subtree FILE_POINTER for the currently loaded record,
+ * considering only the first @n branches. 
+ * This function will find the top node of the branch, based upon a
+ * partial key. Key length to be considered must be specified.
+ * 
+ **/
+FILE_POINTER dbh_find_top (DBHashTable * dbh, int n);
+
+
 /**
  * dbh_find:
  * @dbh: A #DBHashTable pointer (#DBHashTable *).
